Learn R Programming

multivariance (version 2.4.1)

mu3.unbiased: given the distance matrix the unbiased estimate for mu3 is computed

Description

given the distance matrix the unbiased estimate for mu3 is computed

Usage

mu3.unbiased(B, b2ob = sum(tcrossprod(B) * B))

Arguments