Learn R Programming

multivariance (version 2.4.1)

sums.of.products: This is the function GC which is required for the computation of the finite sample variance for m and total multivariance

Description

This is the function GC which is required for the computation of the finite sample variance for m and total multivariance

Usage

sums.of.products(a, b, c, type = "multi")

Arguments