fastEuclideanCdm: fast centered Euclidean distance matrix
Description
fast centered Euclidean distance matrix
Usage
fastEuclideanCdm(x, normalize)
Arguments
x
matrix with sample rows for which the distance matrix is computed (to use with vectors, use as.matrix(x))
normalize
boolean. If TRUE the matrix will be normalized to mean 1.