This function creates samples of a tetrahedron-dice colored r, g, b and rgb. Each sample indicates if for the thrown dice the colors r, g and b are contained on the bottom side of the dice.
Usage
tetrahedron(N = 1000)
Arguments
N
number of samples
Value
It returns the samples of the events r, g and b as rows of a N by 3 matrix (the first column corresponds to r, the second to g,...). TRUE indicates that this color is on the bottom side of the dice. The columns are dependent but 2-independent.
References
For the theoretic background see the reference [3] given on the main help page of this package: multivariance-package.